Editor

Struct Editor 

pub struct Editor {
    pub config: Config,
    /* private fields */
}
Interactive line editor instance.

Fields

config: Config

Configuration for this editor instance.

Implementations

Source

impl Editor

pub fn new() -> Self

Creates a new editor with default configuration.

pub fn with_config(config: Config) -> Self

Creates a new editor with the specified configuration.

pub fn readline( &mut self, prompt: impl AsRef<BStr>, ) -> Result<BString, ReadlineError>

Reads a line from stdin/stdout using this editor.

pub fn readline_from<R: Read, W: Write>( &mut self, reader: R, writer: W, mode: OperatingMode, prompt: impl AsRef<BStr>, ) -> Result<BString, ReadlineError>

Reads a line from the provided reader and writer streams using the specified operating mode.

pub fn readline_stream<R: Read, W: Write>( &mut self, reader: &mut R, writer: &mut W, prompt: &BStr, ) -> Result<BString, ReadlineError>

Reads a line directly from raw reader and writer streams in interactive mode.

pub fn set_completion_handler<H: CompletionHandler + 'static>( &mut self, handler: H, )

Registers a completion handler for tab autocompletion.

pub fn clear_completion_handler(&mut self)

Removes any registered completion handler.

pub fn set_hint_handler<H: HintHandler + 'static>(&mut self, handler: H)

Registers a hint handler for inline completions/hints.

pub fn clear_hint_handler(&mut self)

Removes any registered hint handler.

pub fn add_history(&mut self, line: impl Into<BString>) -> bool

Adds a line to the editor’s history buffer.

Returns true if the entry was added (deduplicating adjacent identical entries).

pub fn history(&self) -> &History

Returns a shared reference to the editor’s history manager.

pub fn history_mut(&mut self) -> &mut History

Returns a mutable reference to the editor’s history manager.

pub fn clear_screen(&self) -> Result<(), Error>

Clears the terminal screen using stdout.

pub fn clear_screen_writer<W: Write>(&self, writer: &mut W) -> Result<(), Error>

Clears the terminal screen using the provided writer.