pub struct Hint {
pub text: BString,
pub color: Option<Color>,
pub bold: bool,
}Expand description
Represents an inline hint displayed alongside the input buffer.
Fields
text: BStringText of the hint.
color: Option<Color>Optional color of the hint text.
bold: boolWhether the hint text should be displayed in bold.
Implementations